clear all
local rootDir "/Users/~/data_jep"

* Data source: This code generates bar charts using coefficient estimates from Appendix Table 1 

import excel using "`rootDir'/data/fig_3.xlsx", first clear
destring lb, replace
destring ub, replace
save "`rootDir'/fig_3/temp.dta", replace

local c1 = 1
local c2 = 15
local l = 11
local h = 6

* a2: monthly electricity spending (usd)
use "`rootDir'/fig_3/temp.dta", clear
keep if outcome=="a2"

twoway ///
	(rbar low high bar if control==1 & bar==1, barw(0.7) fcolor(gs`c1') lcolor(gs`c1') lwidth(vvthin)) ///
	(rbar low high bar if control==0 & bar==2, barw(0.7) fcolor(gs`l') lcolor(gs`c1') lwidth(vvthin)) ///
	(rbar low high bar if control==0 & bar==3, barw(0.7) fcolor(gs`h') lcolor(gs`c1') lwidth(vvthin)) ///
	(rcap lb ub bar, lcolor(gs2) lwidth(thin)), ///
	ylabel(0(1)4, labsize(large)) ///
	xlabel(1 " " 2 " " 3 " ", labsize(medsmall)) ///
	xtick(1(1)3) ///
	xscale(range(1,3)) ///
	ytitle("", size(large) margin(medsmall)) ///
	xtitle("", size(medsmall) margin(medsmall)) ///
	yline(0, lwidth(vthin) lcolor(gs10)) ///
	scheme(s1mono) ///
	legend(off) ///	
	plotr(margin(8 8 0.15 0.15)) ///
	xsize(4.1) ysize(2.8)
	graph export "`rootDir'/fig_3/fig_3a.png", replace

* b2: number of appliance types owned	
use "`rootDir'/fig_3/temp.dta", clear
keep if outcome=="b2"

twoway ///
	(rbar low high bar if control==1 & bar==1, barw(0.7) fcolor(gs`c1') lcolor(gs`c1') lwidth(vvthin)) ///
	(rbar low high bar if control==0 & bar==2, barw(0.7) fcolor(gs`l') lcolor(gs`c1') lwidth(vvthin)) ///
	(rbar low high bar if control==0 & bar==3, barw(0.7) fcolor(gs`h') lcolor(gs`c1') lwidth(vvthin)) ///
	(rcap lb ub bar, lcolor(gs2) lwidth(thin)), ///
	ylabel(0(1)4, labsize(large)) ///
	xlabel(1 " " 2 " " 3 " ", labsize(medsmall)) ///
	xtick(1(1)3) ///
	xscale(range(1,3)) ///
	ytitle("", size(large) margin(medsmall)) ///
	xtitle("", size(medsmall) margin(medsmall)) ///
	yline(0, lwidth(vthin) lcolor(gs10)) ///
	scheme(s1mono) ///
	legend(off) ///	
	plotr(margin(8 8 0.15 0.15)) ///
	xsize(4.1) ysize(2.8)
	graph export "`rootDir'/fig_3/fig_3b.png", replace

* b7: monthly kerosene spending (USD)	
use "`rootDir'/fig_3/temp.dta", clear
keep if outcome=="b7"

twoway ///
	(rbar low high bar if control==1 & bar==1, barw(0.7) fcolor(gs`c1') lcolor(gs`c1') lwidth(vvthin)) ///
	(rbar low high bar if control==0 & bar==2, barw(0.7) fcolor(gs`l') lcolor(gs`c1') lwidth(vvthin)) ///
	(rbar low high bar if control==0 & bar==3, barw(0.7) fcolor(gs`h') lcolor(gs`c1') lwidth(vvthin)) ///
	(rcap lb ub bar, lcolor(gs2) lwidth(thin)), ///
	ylabel(0(1)3, labsize(large)) ///
	xlabel(1 " " 2 " " 3 " ", labsize(medsmall)) ///
	xtick(1(1)3) ///
	xscale(range(1,3)) ///
	ytitle("", size(large) margin(medsmall)) ///
	xtitle("", size(medsmall) margin(medsmall)) ///
	scheme(s1mono) ///
	legend(off) ///	
	plotr(margin(8 8 0.15 0.15)) ///
	xsize(4.1) ysize(2.8)
	graph export "`rootDir'/fig_3/fig_3c.png", replace

* c1: household employed or own business (%)	
use "`rootDir'/fig_3/temp.dta", clear
keep if outcome=="c1"

twoway ///
	(rbar low high bar if control==1 & bar==1, barw(0.7) fcolor(gs`c1') lcolor(gs`c1') lwidth(vvthin)) ///
	(rbar low high bar if control==0 & bar==2, barw(0.7) fcolor(gs`l') lcolor(gs`c1') lwidth(vvthin)) ///
	(rbar low high bar if control==0 & bar==3, barw(0.7) fcolor(gs`h') lcolor(gs`c1') lwidth(vvthin)) ///
	(rcap lb ub bar, lcolor(gs2) lwidth(thin)), ///
	ylabel(0(20)102, labsize(large)) ///
	xlabel(1 " " 2 " " 3 " ", labsize(medsmall)) ///
	xtick(1(1)3) ///
	xscale(range(1,3)) ///
	ytitle("", size(large) margin(medsmall)) ///
	xtitle("", size(medsmall) margin(medsmall)) ///
	yline(0, lwidth(vthin) lcolor(gs10)) ///
	scheme(s1mono) ///
	legend(off) ///	
	plotr(margin(8 8 0.15 0.15)) ///
	xsize(4.1) ysize(2.8)
	graph export "`rootDir'/fig_3/fig_3d.png", replace

* c4: total asset value (usd)	
use "`rootDir'/fig_3/temp.dta", clear
keep if outcome=="c4"

twoway ///
	(rbar low high bar if control==1 & bar==1, barw(0.7) fcolor(gs`c1') lcolor(gs`c1') lwidth(vvthin)) ///
	(rbar low high bar if control==0 & bar==2, barw(0.7) fcolor(gs`l') lcolor(gs`c1') lwidth(vvthin)) ///
	(rbar low high bar if control==0 & bar==3, barw(0.7) fcolor(gs`h') lcolor(gs`c1') lwidth(vvthin)) ///
	(rcap lb ub bar, lcolor(gs2) lwidth(thin)), ///
	ylabel(0(0.5)2.5, labsize(large)) ///
	xlabel(1 " " 2 " " 3 " ", labsize(medsmall)) ///
	xtick(1(1)3) ///
	xscale(range(1,3)) ///
	ytitle("", size(large) margin(medsmall)) ///
	xtitle("", size(medsmall) margin(medsmall)) ///
	yline(0, lwidth(vthin) lcolor(gs10)) ///
	scheme(s1mono) ///
	legend(off) ///	
	plotr(margin(8 8 0.15 0.15)) ///
	xsize(4.1) ysize(2.8)
	graph export "`rootDir'/fig_3/fig_3e.png", replace

* d1: recent health status index	
use "`rootDir'/fig_3/temp.dta", clear
keep if outcome=="d1"

twoway ///
	(rbar low high bar if control==1 & bar==1, barw(0.7) fcolor(gs`c1') lcolor(gs`c1') lwidth(vvthin)) ///
	(rbar low high bar if control==0 & bar==2, barw(0.7) fcolor(gs`l') lcolor(gs`c1') lwidth(vvthin)) ///
	(rbar low high bar if control==0 & bar==3, barw(0.7) fcolor(gs`h') lcolor(gs`c1') lwidth(vvthin)) ///
	(rcap lb ub bar, lcolor(gs2) lwidth(thin)), ///
	ylabel(-0.8(0.2)0.8, labsize(large)) ///
	xlabel(1 " " 2 " " 3 " ", labsize(medsmall)) ///
	xtick(1(1)3) ///
	xscale(range(1,3)) ///
	ytitle("", size(large) margin(medsmall)) ///
	xtitle("", size(medsmall) margin(medsmall)) ///
	yline(0, lwidth(vthin) lcolor(gs10)) ///
	scheme(s1mono) ///
	legend(off) ///	
	plotr(margin(8 8 0.15 0.15)) ///
	xsize(4.1) ysize(2.8)
	graph export "`rootDir'/fig_3/fig_3f.png", replace

rm "`rootDir'/fig_3/temp.dta"

