clear all
local rootDir "/Users/~/data_jep"

local data "`rootDir'/data"
local out "`rootDir'/tab_A3_A4"

* annual average exchange rates
local xr_14 = 87.94
local xr_16 = 101.53
local xr_17 = 103.41

* annual average inflation
local i_15 = 0.0801
local i_16 = 0.0635
local i_17 = 0.0450

local x_16 = (1+`i_16')*(1+`i_15')*`xr_14'
di `x_16'
* 101.015 KES/USD
local x_17 = (1+`i_17')*(1+`i_16')*(1+`i_15')*`xr_14'
di `x_17'
* 105.561

********************************************************************************
* Appendix Table A3, A4 - Exploring Heterogeneity w/ Interactions
* Last updated: 4 November 2019
********************************************************************************

********************************************************************************
* 1. Load data
********************************************************************************

use `data'/impacts_1.dta, clear
local base base_energyspending_ksh base_asset_value_ksh
local r1 gridelec_spending_ksh kerosene_spending_ksh energy_spending_ksh asset_value_ksh percapcons_ksh

foreach var in `base' {
	gen `var'_x=`var'/`xr_14'
	qui sum `var', detail
	local label : var lab `var'
	la var `var'_x "`label' (converted to USD)"
}
foreach var in `r1' {
	gen `var'_x=`var'/`x_16'
	qui sum `var', detail
	local label : var lab `var'
	la var `var'_x "`label' (converted to USD)"
}

keep reppid siteno hhid child treat_low treat_med treat_full treated_all ///
	busia base_market base_population base_connected_rate base_transearly ///
	base_connected base_housing base_bank base_energyspending_ksh_x base_female base_age base_educ base_asset_value_ksh_x ///
	female age_resp child_age child_female sibs ///
	connected gridelec_spending_ksh_x fraction_employed_all fraction_employed_f fraction_employed_m hours_worked asset_value_ksh_x percapcons_ksh_x symptoms_index life_index st_studenttest st_studenttest_avg st_studenttest_f st_studenttest_m knowledge_index ///
	electric_lighting number_appliances mobilephone radio television iron kerosene_spending_ksh_x energy_spending_ksh_x solar_shs ///
	EMI NEMI moved round metered survey

order reppid siteno hhid child treat_low treat_med treat_full treated_all ///
	busia base_market base_population base_connected_rate base_transearly ///
	base_connected base_housing base_bank base_energyspending_ksh_x base_female base_age base_educ base_asset_value_ksh_x ///
	female age_resp child_age child_female sibs ///
	connected gridelec_spending_ksh_x fraction_employed_all fraction_employed_f fraction_employed_m hours_worked asset_value_ksh_x percapcons_ksh_x symptoms_index life_index st_studenttest st_studenttest_avg st_studenttest_f st_studenttest_m knowledge_index ///
	electric_lighting number_appliances mobilephone radio television iron kerosene_spending_ksh_x energy_spending_ksh_x solar_shs ///
	EMI NEMI moved round metered survey

foreach var in base_energyspending_ksh_x base_asset_value_ksh_x gridelec_spending_ksh_x asset_value_ksh_x percapcons_ksh_x kerosene_spending_ksh_x energy_spending_ksh_x  {
   	local newname = subinstr("`var'", "_ksh_x", "",1)
   	rename `var' `newname'
}

drop if base_connected==1

save `data'/temp.dta, replace

******

use "`data'/demand.dta", clear
sort reppid
rename radio radio_b
rename television television_b
save `data'/temp2.dta, replace

use `data'/temp.dta, clear
sort reppid
merge reppid using `data'/temp2.dta
drop _merge

foreach var in base_educ notfarmer employed base_bank {
	replace `var'=`var'*100
}

********************************************************************************
* 2. Construct SES index + Report correlations at baseline 
********************************************************************************

local het "base_educ notfarmer employed base_bank earn base_asset_value"
gen ses=0
foreach var in `het'{
	sum `var'
	gen norm`var'=(`var'-`r(mean)')/`r(sd)'
	replace ses=ses + norm`var'
}

estpost corr base_educ notfarmer employed base_bank earn base_asset_value, matrix listwise
esttab using `out'/tab_A3.tex, replace unstack not nostar noobs compress

sum ses, detail
gen highses=ses>`r(p75)'
replace highses=. if ses==.

* copy highses values for child==1 observations
bysort siteno hhid: egen temp=max(highses)
replace highses=temp if highses==.
drop temp

********************************************************************************
* 3. TOT regressions with High SES Index interactions 
********************************************************************************

foreach x in connected electric_lighting solar_shs mobilephone radio television iron {
	replace `x'= 100 if `x'==1
}

local outcomes1 gridelec_spending electric_lighting number_appliances mobilephone radio television iron kerosene_spending energy_spending solar_shs ///
	fraction_employed_all fraction_employed_f fraction_employed_m hours_worked asset_value percapcons symptoms_index life_index knowledge_index EMI NEMI
local outcomes2 st_studenttest

local int highses

local treatment "treat_low treat_med treat_full"

local community busia base_market base_transearly base_connected_rate base_population 
local household female age base_housing base_energyspending
local students base_housing base_energyspending child_female child_age sibs

foreach y in `outcomes1' {
	di ""
	di ""
	di "********************************************************************************************"
	di "DepVar: `y'"
	di "Round: `round'"
	di ""
	di "(1) Mean values for the control group"
	su `y' if treat_low==0 & treat_med==0 & treat_full==0 & child==0
	local m_`y' = round(`r(mean)', .01)
	local sd_`y' = round(`r(sd)', .01)
	di "m: `m_`y''"
	di "sd: `sd_`y''"
	di ""
	di "(2) TOT regressions"
	replace connected= 1 if connected==100
	ivreg2 `y' `int' `community' `household' (connected c.connected#c.`int' = ///
		treat_low treat_med treat_full c.treat_low#c.`int' c.treat_med#c.`int' c.treat_full#c.`int') ///
		if child==0, cl(siteno)
	mat b = e(b)
	mat v = e(V)
	local b_x_`y' = round(b[1,1], .001)
	local b_int_`y' = round(b[1,3], .001)
	local b_xint_`y' = round(b[1,2], .001)
	local se_x_`y' = round(v[1,1]^0.5, .001)
	local se_int_`y' = round(v[3,3]^0.5, .001)
	local se_xint_`y' = round(v[2,2]^0.5, .001)
	local n_`y' = e(N)
	di "b_x: `b_x_`y''"
	di "se_x: `se_x_`y''"
	di "b_int: `b_int_`y''"
	di "se_int: `se_int_`y''"
	di "b_xint: `b_xint_`y''"
	di "se_xint: `se_xint_`y''"
	di "n: `n_`y''"
	replace connected= 100 if connected==1
}

foreach y in `outcomes2' {
	di ""
	di ""
	di "********************************************************************************************"
	di "DepVar: `y'"
	di "Round: `round'"
	di ""
	di "(1) Mean values for the control group"
	su `y' if treat_low==0 & treat_med==0 & treat_full==0 & child==1
	local m_`y' = round(`r(mean)', .01)
	local sd_`y' = round(`r(sd)', .01)
	di "m: `m_`y''"
	di "sd: `sd_`y''"
	di ""
	di "(2) TOT regressions"	
	ivreg2 `y' `int' `community' `students' (connected c.connected#c.`int' = ///
		treat_low treat_med treat_full c.treat_low#c.`int' c.treat_med#c.`int' c.treat_full#c.`int') ///
		if child==1, cl(siteno)
	mat b = e(b)
	mat v = e(V)
	local b_x_`y' = round(b[1,1], .001)
	local b_int_`y' = round(b[1,3], .001)
	local b_xint_`y' = round(b[1,2], .001)
	local se_x_`y' = round(v[1,1]^0.5, .001)
	local se_int_`y' = round(v[3,3]^0.5, .001)
	local se_xint_`y' = round(v[2,2]^0.5, .001)
	local n_`y' = e(N)
	di "b_x: `b_x_`y''"
	di "se_x: `se_x_`y''"
	di "b_int: `b_int_`y''"
	di "se_int: `se_int_`y''"
	di "b_xint: `b_xint_`y''"
	di "se_xint: `se_xint_`y''"
	di "n: `n_`y''"
}

* generate summary csv table
drop _all
set obs 66
local v = 22
local v2 = `v'*2
local v3 = `v'*3
g no = .
g var_name = ""
g des = ""
g m1 = .
g b1 = .
g b2 = .
g b3 = .

local n = 1
foreach y in `outcomes1' `outcomes2' {
	replace var_name = "`y'" if _n==`n'
	replace m1 = `m_`y'' if _n==`n'
	replace b1 = `b_x_`y'' if _n==`n'
	replace b2 = `b_int_`y'' if _n==`n'
	replace b3 = `b_xint_`y'' if _n==`n'
	replace des = "1. mean / b" if _n==`n' 
	replace no = `n' if _n==`n'

	replace var_name = "`y'" if _n==`n'+`v'
	replace m1 = `sd_`y'' if _n==`n'+`v'
	replace b1 = `se_x_`y'' if _n==`n'+`v'
	replace b2 = `se_int_`y'' if _n==`n'+`v'
	replace b3 = `se_xint_`y'' if _n==`n'+`v'
	replace des = "2. sd / se" if _n==`n'+`v' 
	replace no = `n' if _n==`n'+`v'

	replace var_name = "`y'" if _n==`n'+`v2'
	replace b1 = `n_`y'' if _n==`n'+`v2'
	replace des = "3. n" if _n==`n'+`v2' 
	replace no = `n' if _n==`n'+`v2'

	local n = `n'+1
}
sort no des

outsheet using `out'/tab_A4.csv, comma replace

rm `data'/temp.dta
rm `data'/temp2.dta











